# Copyright 2009-2012 IEAP CTU
# Author: Daniel Turecek (daniel.turecek@utef.cvut.cz)
"""
This module is just helper wrapper around often used GUI stuff such as Dialogs, Progress window ...
"""
from javax.swing import JButton, JFrame, JPanel, JOptionPane, JLabel, JPanel
from cz.ieap.pixelman.shared.dialogs import OpenSaveFileDialog
from net.miginfocom.swing import MigLayout
from javax.swing import JFileChooser
from java.io import File


def showMsg(message):
    """Show message box with a message"""
    JOptionPane.showMessageDialog(None, message)

def showErrorMsg(message, title="Error"):
    """Shows message box with error message"""
    JOptionPane.showMessageDialog(None, message, title, JOptionPane.ERROR_MESSAGE)

def showInfoMsg(message, title="Information"):
    """Shows message box with information message"""
    JOptionPane.showMessageDialog(None, message, title, JOptionPane.INFORMATION_MESSAGE)

def showWarningMsg(message, title="Warning"):
    """Shows message box with warning message"""
    JOptionPane.showMessageDialog(None, message, title, JOptionPane.WARNING_MESSAGE)

def showYesNoMsg(message, title="Question"):
    """Shows message box with question message and gets response of the user
    returns True if user select Yes, and False when No is selected
    """
    return JOptionPane.showConfirmDialog(None, message, title, JOptionPane.YES_NO_OPTION) == JOptionPane.YES_OPTION

def showInputMsg(message, defaultValue):
    """Shows message box with input box and return value inputed by user. defaultValue is filled into input box when 
    dialog is shown.
    """
    return JOptionPane.showInputDialog(None, message, defaultValue)

def showChooseMsg(message, values, defaultValue, title="Question"):
    """Shows message box with possiblity to choose from several values. Chosen value is returned"""
    return JOptionPane.showInputDialog(None, message, title, JOptionPane.QUESTION_MESSAGE, None, values, defaultValue)

def showOpenDialog():
    """Shows open dialog with default filter all files "*.*" and returns selected file. None is returned if user cancels dialog."""
    return OpenSaveFileDialog.showDialog(True, None, "Open dialog", OpenSaveFileDialog.ALL_FILES)

def showSelectDirDialog(startdir=None):
    """Shows open dialog where user can select directory"""
    if startdir is None:
        return OpenSaveFileDialog.showDirectorySelectDialog(None, "Select directory")
    dialog = JFileChooser()
    dialog.setFileSelectionMode(JFileChooser.DIRECTORIES_ONLY)
    dialog.setDialogTitle("Select directory")
    dialog.setCurrentDirectory(File(startdir))
    res = dialog.showOpenDialog(None);
    if res == JFileChooser.APPROVE_OPTION:
        fileName = dialog.getSelectedFile().getAbsolutePath()
        return fileName

def showSaveDialog():
    """Shows save dialog with default filter all files "*.*" and returns selected file. None is returned if use cancels dialog"""
    return OpenSaveFileDialog.showDialog(False, None, "Save dialog", OpenSaveFileDialog.ALL_FILES)

class StatusWnd():
    """Class that shows small window in the center of screen with adjustable message. Usefull for all kinds
    of progress and status messages. 
    Example of usage:
    def abortFunction():
        print "Status window: abort button pressed"

    statusWnd = gui.StatusWindow("Progress message", abortFunction")
    # something .....
    statusWnd.close()
    """
    def __init__(self, message, abortFunc, closeOnAbort=False):
        self.abortFunc = abortFunc
        self.pnlMain = JPanel(MigLayout("","[center,grow]","[] 15  []"))
        self.lblStatus = JLabel(message)
        self.btnAbort = JButton("Abort", actionPerformed=self.abort)
        self.pnlMain.add(self.lblStatus, "wrap")
        self.pnlMain.add(self.btnAbort, "")
        self.frame = JFrame("Status", size=(600, 120))
        self.frame.add(self.pnlMain)
        self.frame.setLocationRelativeTo(None)
        self.frame.setVisible(True)
        self.closeOnAbort=closeOnAbort

    def abort(self, event):
        self.abortFunc()
        if self.closeOnAbort:
            self.close()

    def setText(self, text):
        self.lblStatus.setText(text)

    def close(self):
        self.frame.setVisible(False)

    def setTitle(self, title):
        self.frame.setTitle(title)

    def setCloseOnAbort(self, closeOnAbort):
        self.closeOnAbort = closeOnAbort


